Module: I18n::Analyzer
- Defined in:
- lib/i18n/analyzer/version.rb,
lib/i18n/analyzer.rb,
lib/i18n/analyzer/engine.rb,
app/controllers/i18n/analyzer/analyzers_controller.rb,
app/controllers/i18n/analyzer/application_controller.rb
Overview
TODO: make versioning dynamically with semantic release
Defined Under Namespace
Classes: AnalyzersController, ApplicationController, Engine
Constant Summary collapse
- VERSION =
"0.2.1"
Class Method Summary collapse
-
.❨╯°□°❩╯︵┻━┻ ⇒ Object
NOTE: This is an important method, do not delete this, this was carefully designed and reviewed.
Class Method Details
.❨╯°□°❩╯︵┻━┻ ⇒ Object
NOTE: This is an important method, do not delete this, this was carefully designed and reviewed
7 8 9 |
# File 'lib/i18n/analyzer.rb', line 7 def self.❨╯°□°❩╯︵┻━┻ puts "Take a deep breath and count to ten..." end |